@@ -3,12 +3,12 @@ import warnings
 import numpy as np
 import pandas as pd
 
-import dask
-from dask.delayed import tokenize
-
-from ... import delayed
-from .. import methods
-from .io import from_delayed, from_pandas
+from dask.base import compute as dask_compute
+from dask.dataframe import methods
+from dask.dataframe.io.io import from_delayed, from_pandas
+from dask.dataframe.utils import pyarrow_strings_enabled
+from dask.delayed import delayed, tokenize
+from dask.utils import parse_bytes
 
 
 def read_sql_query(
@@ -123,6 +123,16 @@ def read_sql_query(
             # no results at all
             return from_pandas(head, npartitions=1)
 
+        if pyarrow_strings_enabled():
+            from dask.dataframe._pyarrow import (
+                check_pyarrow_string_supported,
+                to_pyarrow_string,
+            )
+
+            check_pyarrow_string_supported()
+            # to estimate partition size with pyarrow strings
+            head = to_pyarrow_string(head)
+
         bytes_per_row = (head.memory_usage(deep=True, index=True)).sum() / head_rows
         if meta is None:
             meta = head.iloc[:0]
@@ -131,7 +141,7 @@ def read_sql_query(
         if limits is None:
             # calculate max and min for given index
             q = sa.sql.select(
-                [sa.sql.func.max(index), sa.sql.func.min(index)]
+                sa.sql.func.max(index), sa.sql.func.min(index)
             ).select_from(sql.subquery())
             minmax = pd.read_sql(q, engine)
             maxi, mini = minmax.iloc[0]
@@ -141,15 +151,10 @@ def read_sql_query(
             dtype = pd.Series(limits).dtype
 
         if npartitions is None:
-            q = sa.sql.select([sa.sql.func.count(index)]).select_from(sql.subquery())
+            q = sa.sql.select(sa.sql.func.count(index)).select_from(sql.subquery())
             count = pd.read_sql(q, engine)["count_1"][0]
             npartitions = (
-                int(
-                    round(
-                        count * bytes_per_row / dask.utils.parse_bytes(bytes_per_chunk)
-                    )
-                )
-                or 1
+                int(round(count * bytes_per_row / parse_bytes(bytes_per_chunk))) or 1
             )
         if dtype.kind == "M":
             divisions = methods.tolist(
@@ -162,7 +167,7 @@ def read_sql_query(
             divisions[0] = mini
             divisions[-1] = maxi
         elif dtype.kind in ["i", "u", "f"]:
-            divisions = np.linspace(mini, maxi, npartitions + 1).tolist()
+            divisions = np.linspace(mini, maxi, npartitions + 1, dtype=dtype).tolist()
         else:
             raise TypeError(
                 'Provided index column is of type "{}".  If divisions is not provided the '
@@ -280,49 +285,18 @@ def read_sql_table(
             DeprecationWarning,
         )
         con = kwargs.pop("uri")
-    deprecated_args = False
+
     if not isinstance(table_name, str):
-        warnings.warn(
-            "`read_sql_table` will no longer support {}; please use a `table_name` of type str instead "
-            "or use `read_sql_query`, if you are using a SQLAlchemy query".format(
-                type(table_name)
-            ),
-            DeprecationWarning,
+        raise TypeError(
+            "`table_name` must be of type str, not " + str(type(table_name))
         )
-        deprecated_args = True
     if columns is not None:
         for col in columns:
             if not isinstance(col, (sa.Column, str)):
-                warnings.warn(
-                    "`columns` will no longer support SQLAlchemy selectables; please use `read_sql_query` "
-                    "instead",
-                    DeprecationWarning,
+                raise TypeError(
+                    "`columns` must be of type List[str], and cannot contain "
+                    + str(type(col))
                 )
-                deprecated_args = True
-
-    if not _gt14():
-        warnings.warn(
-            "Dask will soon require SQLAlchemy 1.4 or newer. "
-            "Please update your SQLAlchemy version. "
-            "Friendly note: Upgrading to SQLAlchemy 1.4 may brake code. Do it with caution. ",
-            category=DeprecationWarning,
-        )
-    if deprecated_args or not _gt14():
-        return _old_read_sql_table(
-            table=table_name,
-            uri=con,
-            index_col=index_col,
-            divisions=divisions,
-            npartitions=npartitions,
-            limits=limits,
-            columns=columns,
-            bytes_per_chunk=bytes_per_chunk,
-            head_rows=head_rows,
-            schema=schema,
-            meta=meta,
-            engine_kwargs=engine_kwargs,
-            **kwargs,
-        )
 
     if not isinstance(con, str):
         raise TypeError(
@@ -335,9 +309,7 @@ def read_sql_table(
     engine = sa.create_engine(con, **engine_kwargs)
     m = sa.MetaData()
     if isinstance(table_name, str):
-        table_name = sa.Table(
-            table_name, m, autoload=True, autoload_with=engine, schema=schema
-        )
+        table_name = sa.Table(table_name, m, autoload_with=engine, schema=schema)
     else:
         raise TypeError(
             "`table_name` must be of type str, not " + str(type(table_name))
@@ -365,7 +337,7 @@ def read_sql_table(
     if index.name not in [c.name for c in columns]:
         columns.append(index)
 
-    query = sql.select(columns).select_from(table_name)
+    query = sql.select(*columns).select_from(table_name)
 
     return read_sql_query(
         sql=query,
@@ -438,231 +410,16 @@ def _read_sql_chunk(q, uri, meta, engine_kwargs=None, **kwargs):
         return df.astype(meta.dtypes.to_dict(), copy=False)
 
 
-def _gt14() -> bool:
-    """
-    Check if sqlalchemy.__version__ is at least 1.4.0, when several
-    deprecations were made.
-    """
-    import sqlalchemy
-
-    if (
-        sqlalchemy.__version__.startswith("0.")
-        or sqlalchemy.__version__.startswith("1.0")
-        or sqlalchemy.__version__.startswith("1.1")
-        or sqlalchemy.__version__.startswith("1.2")
-        or sqlalchemy.__version__.startswith("1.3")
-    ):
-        return False
-    else:
-        return True
-
-
-def _old_read_sql_table(
-    table,
-    uri,
-    index_col,
-    divisions=None,
-    npartitions=None,
-    limits=None,
-    columns=None,
-    bytes_per_chunk="256 MiB",
-    head_rows=5,
-    schema=None,
-    meta=None,
-    engine_kwargs=None,
-    **kwargs,
-):
-    """
-    Create dataframe from an SQL table.
-    If neither divisions or npartitions is given, the memory footprint of the
-    first few rows will be determined, and partitions of size ~256MB will
-    be used.
-    Parameters
-    ----------
-    table : string or sqlalchemy expression
-        Select columns from here.
-    uri : string
-        Full sqlalchemy URI for the database connection
-    index_col : string
-        Column which becomes the index, and defines the partitioning. Should
-        be a indexed column in the SQL server, and any orderable type. If the
-        type is number or time, then partition boundaries can be inferred from
-        npartitions or bytes_per_chunk; otherwide must supply explicit
-        ``divisions=``.
-        ``index_col`` could be a function to return a value, e.g.,
-        ``sql.func.abs(sql.column('value')).label('abs(value)')``.
-        ``index_col=sql.func.abs(sql.column("value")).label("abs(value)")``, or
-        ``index_col=cast(sql.column("id"),types.BigInteger).label("id")`` to convert
-        the textfield ``id`` to ``BigInteger``.
-        Note ``sql``, ``cast``, ``types`` methods comes from ``sqlalchemy`` module.
-        Labeling columns created by functions or arithmetic operations is
-        required.
-    divisions: sequence
-        Values of the index column to split the table by. If given, this will
-        override npartitions and bytes_per_chunk. The divisions are the value
-        boundaries of the index column used to define the partitions. For
-        example, ``divisions=list('acegikmoqsuwz')`` could be used to partition
-        a string column lexographically into 12 partitions, with the implicit
-        assumption that each partition contains similar numbers of records.
-    npartitions : int
-        Number of partitions, if divisions is not given. Will split the values
-        of the index column linearly between limits, if given, or the column
-        max/min. The index column must be numeric or time for this to work
-    limits: 2-tuple or None
-        Manually give upper and lower range of values for use with npartitions;
-        if None, first fetches max/min from the DB. Upper limit, if
-        given, is inclusive.
-    columns : list of strings or None
-        Which columns to select; if None, gets all; can include sqlalchemy
-        functions, e.g.,
-        ``sql.func.abs(sql.column('value')).label('abs(value)')``.
-        Labeling columns created by functions or arithmetic operations is
-        recommended.
-    bytes_per_chunk : str, int
-        If both divisions and npartitions is None, this is the target size of
-        each partition, in bytes
-    head_rows : int
-        How many rows to load for inferring the data-types, unless passing meta
-    meta : empty DataFrame or None
-        If provided, do not attempt to infer dtypes, but use these, coercing
-        all chunks on load
-    schema : str or None
-        If using a table name, pass this to sqlalchemy to select which DB
-        schema to use within the URI connection
-    engine_kwargs : dict or None
-        Specific db engine parameters for sqlalchemy
-    kwargs : dict
-        Additional parameters to pass to `pd.read_sql()`
-    Returns
-    -------
-    dask.dataframe
-    Examples
-    --------
-    >>> df = dd.read_sql_table('accounts', 'sqlite:///path/to/bank.db',
-    ...                  npartitions=10, index_col='id')  # doctest: +SKIP
-    """
+def _to_sql_chunk(d, uri, engine_kwargs=None, **kwargs):
     import sqlalchemy as sa
-    from sqlalchemy import sql
-    from sqlalchemy.sql import elements
 
-    warnings.warn(
-        "You are using a compatibility version of `read_sql_table` that will be "
-        "removed in a future version of dask. This function existst to support "
-        "old versions of SQLAlchemy (< 1.4). This compatibility function is less "
-        "stable than the new version. We recommend you update your code.",
-        DeprecationWarning,
-    )
-
-    if index_col is None:
-        raise ValueError("Must specify index column to partition on")
-
-    engine_kwargs = {} if engine_kwargs is None else engine_kwargs
+    engine_kwargs = engine_kwargs or {}
     engine = sa.create_engine(uri, **engine_kwargs)
-    m = sa.MetaData()
-    if isinstance(table, str):
-        table = sa.Table(table, m, autoload=True, autoload_with=engine, schema=schema)
-
-    index = table.columns[index_col] if isinstance(index_col, str) else index_col
-    if not isinstance(index_col, (str, elements.Label)):
-        raise ValueError(
-            "Use label when passing an SQLAlchemy instance as the index (%s)" % index
-        )
-    if divisions and npartitions:
-        raise TypeError("Must supply either divisions or npartitions, not both")
-
-    columns = (
-        [(table.columns[c] if isinstance(c, str) else c) for c in columns]
-        if columns
-        else list(table.columns)
-    )
-    if index not in columns:
-        columns.append(index)
-
-    if isinstance(index_col, str):
-        kwargs["index_col"] = index_col
-    else:
-        # function names get pandas auto-named
-        kwargs["index_col"] = index_col.name
-
-    if head_rows > 0:
-        # derive metadata from first few rows
-        q = sql.select(columns).limit(head_rows).select_from(table)
-        head = pd.read_sql(q, engine, **kwargs)
-
-        if len(head) == 0:
-            # no results at all
-            name = table.name
-            schema = table.schema
-            head = pd.read_sql_table(name, uri, schema=schema, index_col=index_col)
-            return from_pandas(head, npartitions=1)
-
-        bytes_per_row = (head.memory_usage(deep=True, index=True)).sum() / head_rows
-        if meta is None:
-            meta = head.iloc[:0]
-    elif meta is None:
-        raise ValueError("Must provide meta if head_rows is 0")
-    else:
-        if divisions is None and npartitions is None:
-            raise ValueError(
-                "Must provide divisions or npartitions when using explicit meta."
-            )
-
-    if divisions is None:
-        if limits is None:
-            # calculate max and min for given index
-            q = sql.select([sql.func.max(index), sql.func.min(index)]).select_from(
-                table
-            )
-            minmax = pd.read_sql(q, engine)
-            maxi, mini = minmax.iloc[0]
-            dtype = minmax.dtypes["max_1"]
-        else:
-            mini, maxi = limits
-            dtype = pd.Series(limits).dtype
-
-        if npartitions is None:
-            q = sql.select([sql.func.count(index)]).select_from(table)
-            count = pd.read_sql(q, engine)["count_1"][0]
-            npartitions = (
-                int(
-                    round(
-                        count * bytes_per_row / dask.utils.parse_bytes(bytes_per_chunk)
-                    )
-                )
-                or 1
-            )
-        if dtype.kind == "M":
-            divisions = methods.tolist(
-                pd.date_range(
-                    start=mini,
-                    end=maxi,
-                    freq="%iS" % ((maxi - mini).total_seconds() / npartitions),
-                )
-            )
-            divisions[0] = mini
-            divisions[-1] = maxi
-        elif dtype.kind in ["i", "u", "f"]:
-            divisions = np.linspace(mini, maxi, npartitions + 1).tolist()
-        else:
-            raise TypeError(
-                'Provided index column is of type "{}".  If divisions is not provided the '
-                "index column type must be numeric or datetime.".format(dtype)
-            )
-
-    parts = []
-    lowers, uppers = divisions[:-1], divisions[1:]
-    for i, (lower, upper) in enumerate(zip(lowers, uppers)):
-        cond = index <= upper if i == len(lowers) - 1 else index < upper
-        q = sql.select(columns).where(sql.and_(index >= lower, cond)).select_from(table)
-        parts.append(
-            delayed(_read_sql_chunk)(
-                q, uri, meta, engine_kwargs=engine_kwargs, **kwargs
-            )
-        )
 
+    q = d.to_sql(con=engine, **kwargs)
     engine.dispose()
 
-    return from_delayed(parts, meta, divisions=divisions)
+    return q
 
 
 def to_sql(
@@ -678,6 +435,7 @@ def to_sql(
     method=None,
     compute=True,
     parallel=False,
+    engine_kwargs=None,
 ):
     """Store Dask Dataframe to a SQL table
 
@@ -734,6 +492,8 @@ def to_sql(
         When true, have each block append itself to the DB table concurrently. This can result in DB rows being in a
         different order than the source DataFrame's corresponding rows. When false, load each block into the SQL DB in
         sequence.
+    engine_kwargs : dict or None
+        Specific db engine parameters for sqlalchemy
 
     Raises
     ------
@@ -764,9 +524,9 @@ def to_sql(
     Create a table from scratch with 4 rows.
 
     >>> import pandas as pd
+    >>> import dask.dataframe as dd
     >>> df = pd.DataFrame([ {'i':i, 's':str(i)*2 } for i in range(4) ])
-    >>> from dask.dataframe import from_pandas
-    >>> ddf = from_pandas(df, npartitions=2)
+    >>> ddf = dd.from_pandas(df, npartitions=2)
     >>> ddf  # doctest: +SKIP
     Dask DataFrame Structure:
                        i       s
@@ -792,7 +552,8 @@ def to_sql(
     # This is the only argument we add on top of what Pandas supports
     kwargs = dict(
         name=name,
-        con=uri,
+        uri=uri,
+        engine_kwargs=engine_kwargs,
         schema=schema,
         if_exists=if_exists,
         index=index,
@@ -802,11 +563,7 @@ def to_sql(
         method=method,
     )
 
-    def make_meta(meta):
-        return meta.to_sql(**kwargs)
-
-    make_meta = delayed(make_meta)
-    meta_task = make_meta(df._meta)
+    meta_task = delayed(_to_sql_chunk)(df._meta, **kwargs)
 
     # Partitions should always append to the empty table created from `meta` above
     worker_kwargs = dict(kwargs, if_exists="append")
@@ -815,7 +572,8 @@ def to_sql(
         # Perform the meta insert, then one task that inserts all blocks concurrently:
         result = [
             _extra_deps(
-                d.to_sql,
+                _to_sql_chunk,
+                d,
                 extras=meta_task,
                 **worker_kwargs,
                 dask_key_name="to_sql-%s" % tokenize(d, **worker_kwargs),
@@ -829,17 +587,18 @@ def to_sql(
         for d in df.to_delayed():
             result.append(
                 _extra_deps(
-                    d.to_sql,
+                    _to_sql_chunk,
+                    d,
                     extras=last,
                     **worker_kwargs,
                     dask_key_name="to_sql-%s" % tokenize(d, **worker_kwargs),
                 )
             )
             last = result[-1]
-    result = dask.delayed(result)
+    result = delayed(result)
 
     if compute:
-        dask.compute(result)
+        dask_compute(result)
     else:
         return result
 
