@@ -4,7 +4,6 @@ from contextlib import contextmanager
 
 import pytest
 
-# import dask
 from dask.dataframe.io.sql import read_sql, read_sql_query, read_sql_table
 from dask.dataframe.utils import assert_eq, get_string_dtype
 from dask.utils import tmpfile
@@ -260,7 +259,10 @@ def test_npartitions(db):
         index_col="number",
         head_rows=1,
     )
-    assert data.npartitions == 2
+    assert (
+        (data.memory_usage_per_partition(deep=True, index=True) < 400).compute().all()
+    )
+    assert (data.name.compute() == df.name).all()
 
 
 def test_divisions(db):
@@ -272,9 +274,8 @@ def test_divisions(db):
     assert_eq(data, df[["name"]][df.index <= 4])
 
 
-@pytest.mark.skip_with_pyarrow_strings  # memory usage is different with pyarrow
 def test_division_or_partition(db):
-    with pytest.raises(TypeError):
+    with pytest.raises(TypeError, match="either 'divisions' or 'npartitions'"):
         read_sql_table(
             "test",
             db,
@@ -285,9 +286,7 @@ def test_division_or_partition(db):
         )
 
     out = read_sql_table("test", db, index_col="number", bytes_per_chunk=100)
-    m = out.map_partitions(
-        lambda d: d.memory_usage(deep=True, index=True).sum()
-    ).compute()
+    m = out.memory_usage_per_partition(deep=True, index=True).compute()
     assert (50 < m).all() and (m < 200).all()
     assert_eq(out, df)
 
@@ -387,7 +386,7 @@ def test_query(db):
     import sqlalchemy as sa
     from sqlalchemy import sql
 
-    s1 = sql.select([sql.column("number"), sql.column("name")]).select_from(
+    s1 = sql.select(sql.column("number"), sql.column("name")).select_from(
         sql.table("test")
     )
     out = read_sql_query(s1, db, npartitions=2, index_col="number")
@@ -395,10 +394,8 @@ def test_query(db):
 
     s2 = (
         sql.select(
-            [
-                sa.cast(sql.column("number"), sa.types.BigInteger).label("number"),
-                sql.column("name"),
-            ]
+            sa.cast(sql.column("number"), sa.types.BigInteger).label("number"),
+            sql.column("name"),
         )
         .where(sql.column("number") >= 5)
         .select_from(sql.table("test"))
@@ -413,7 +410,7 @@ def test_query_index_from_query(db):
 
     number = sql.column("number")
     name = sql.column("name")
-    s1 = sql.select([number, name, sql.func.length(name).label("lenname")]).select_from(
+    s1 = sql.select(number, name, sql.func.length(name).label("lenname")).select_from(
         sql.table("test")
     )
     out = read_sql_query(s1, db, npartitions=2, index_col="lenname")
@@ -435,7 +432,7 @@ def test_query_with_meta(db):
     meta = pd.DataFrame(data, index=index)
 
     s1 = sql.select(
-        [sql.column("number"), sql.column("name"), sql.column("age")]
+        sql.column("number"), sql.column("name"), sql.column("age")
     ).select_from(sql.table("test"))
     out = read_sql_query(s1, db, npartitions=2, index_col="number", meta=meta)
     # Don't check dtype for windows https://github.com/dask/dask/issues/8620
@@ -451,7 +448,7 @@ def test_no_character_index_without_divisions(db):
 def test_read_sql(db):
     from sqlalchemy import sql
 
-    s = sql.select([sql.column("number"), sql.column("name")]).select_from(
+    s = sql.select(sql.column("number"), sql.column("name")).select_from(
         sql.table("test")
     )
     out = read_sql(s, db, npartitions=2, index_col="number")
